=====
Komut
=====

Komut is a high-magic CLI framework.

This release is the initial spin-off from the primary user it was
developed under. It needs design adjustments, refactoring, testing,
documentation. Those will come later. For now, this is not exactly fit
for production use.

License
=======
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <https://www.gnu.org/licenses/>
